@@ -2,7 +2,8 @@ package Reddit::Client;
 
 # Remember to include new version and date in the docs, or get rid of that 
 # section altogether
-our $VERSION = '1.34'; # 7/30 mute and unmute 
+our $VERSION = '1.341'; # 7/30 removed warnings, they're stupid
+# 7/30 mute and unmute 
 # 1.33 7/10 corrected 'edited' to not be boolean
 # 5/29 1.32 unban
 # 5/3 .315 submit_comment now returns fullname not id
@@ -24,7 +25,7 @@ our $VERSION = '1.34'; # 7/30 mute and unmute
 $VERSION = eval $VERSION;
 
 use strict;
-use warnings;
+#use warnings;
 use Carp;
 
 use Data::Dumper   qw/Dumper/;
